"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateCoverages = void 0;
const utils_1 = require("../utils");
const transform_1 = require("../postcss/transform");
const fs_extra_1 = require("fs-extra");
// 生成覆盖
const generateCoverage = async ({ ruleOption, options, }) => {
    const { styleFilePath, ...lastOptions } = ruleOption;
    const { joinFullPath, force } = options;
    // 获取真实的备份 less 文件路径
    const realBackupStyleFilePath = (0, utils_1.getBackupFilePath)(styleFilePath);
    // 拼接完整备份 less 文件路径
    const backupFilePath = joinFullPath(realBackupStyleFilePath);
    // 如果备份文件存在，并且不是强制覆盖的话，就跳过
    if ((0, fs_extra_1.existsSync)(backupFilePath) && !force) {
        return;
    }
    // 拼接完整的less 文件路径
    const realStyleFilePath = joinFullPath(styleFilePath);
    // 如果有备份，那就读取备份的文件内容
    const readFilePath = (0, fs_extra_1.existsSync)(backupFilePath)
        ? backupFilePath
        : realStyleFilePath;
    const transformResult = await (0, transform_1.transformLessToCssVariable)(readFilePath, lastOptions);
    if (!transformResult) {
        throw new Error('');
    }
    const realStyleFilePathByNorm = joinFullPath(styleFilePath);
    const backupFilePathByNorm = joinFullPath(realBackupStyleFilePath);
    if (!(force && (0, fs_extra_1.existsSync)(backupFilePathByNorm))) {
        // 先备份
        await (0, fs_extra_1.copyFile)(realStyleFilePathByNorm, backupFilePathByNorm);
    }
    return (0, fs_extra_1.writeFile)(realStyleFilePathByNorm, transformResult.css || transformResult.content || '');
};
const generateCoverages = (replaceVariableRules, options) => {
    return Promise.all(replaceVariableRules.map((ruleOption) => generateCoverage({ options, ruleOption })));
};
exports.generateCoverages = generateCoverages;
