"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateVariables = void 0;
const context_1 = require("../context");
const color_1 = require("../constants/color");
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const util_1 = require("../../client/util");
const FUNCTION_TOKEN_RE = /(\w+)-(\w+)--(\w+)--(\d{1,2})/;
async function transformPresetColorToVar() {
    const aliasColors = [];
    const addonColors = [];
    for (const [key, value] of color_1.ANT_DESIGN_COLOR_MAP) {
        value.forEach((color) => {
            addonColors.push(color);
            aliasColors.push({
                color,
                alias: key.replace(new RegExp(`^${color_1.ANT_DESIGN_BASE_COLOR}`), color_1.PRIMARY_KEY),
            });
        });
    }
    for (const [key, value] of context_1.antDesignColorMap) {
        const match = key.match(FUNCTION_TOKEN_RE);
        if (match) {
            const [, varName, varNum, funcName, colorDepth] = match;
            if (value !== util_1.__ANT_DESIGN_FUNCTION_TOKEN__ ||
                funcName !== 'colorPalette' ||
                (!color_1.ANT_DESIGN_PRESET_COLOR_LIST.includes(varName) &&
                    !addonColors.includes(`${varName}-${varNum}`))) {
                continue;
            }
            // 6位主色，主色已经转换过
            if (parseInt(varNum) === 6) {
                context_1.antDesignColorMap.set(key, `var(--${varName}-${colorDepth})`);
            }
            else if (varName === color_1.PRIMARY_KEY) {
                context_1.antDesignColorMap.set(key, `var(--${color_1.PRIMARY_KEY}-${colorDepth})`);
            }
            else {
                const aliasColor = aliasColors.find((item) => item.color === `${varName}-${varNum}`);
                if (aliasColor) {
                    context_1.antDesignColorMap.set(key, `var(--${aliasColor.alias})`);
                }
            }
        }
    }
}
function setEnvColor() {
    color_1.REVERT_COLOR_MAP.forEach((item) => {
        const [key, values] = item;
        values.forEach((val) => {
            context_1.antDesignColorMap.set(val, `var(--${key})`);
        });
    });
}
async function generateVariables() {
    // 处理 预置函数转换为 var()
    await transformPresetColorToVar();
    // 需要计算的函数转换
    let variables = ``;
    let convertedVariables = ``;
    let unCoverVariables = ``;
    setEnvColor();
    for (const [key, value] of context_1.antDesignColorMap) {
        if (value.startsWith('var(')) {
            convertedVariables += `\t"--${key}": "${value}",\n`;
        }
        else if (value === util_1.__ANT_DESIGN_FUNCTION_TOKEN__) {
            const match = key.match(util_1.COLOR_FN_RE);
            if (match) {
                const matchKey = match?.[1];
                if (context_1.antDesignColorMap.has(matchKey)) {
                    unCoverVariables += `\t"${key}": "${value}",\n`;
                }
                // else {
                //   console.log(key);
                // }
            }
        }
        else {
            variables += `\t"${key}": "${value}",\n`;
        }
    }
    fs_extra_1.default.outputFileSync(path_1.default.resolve(__dirname, '../../../es/less-variables.js'), `export default {\n${variables}}\n export const unCoverVariable = {\n${unCoverVariables}}\nexport const convertedVariables = {\n${convertedVariables}}\n`, {
        encoding: 'utf8',
    });
}
exports.generateVariables = generateVariables;
