"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../../utils");
const context_1 = require("../../context");
const color_1 = require("../../constants/color");
const color_func_1 = require("../../color-func");
const index_1 = require("../index");
const util_1 = require("../../../client/util");
const is_color_1 = __importDefault(require("is-color"));
const rule = (0, utils_1.defineRuleOptions)({
    styleFilePath: 'style/themes/default.less',
    atRules: [
        (atRule) => {
            const value = atRule.value?.replace(/^@/, '');
            if (!value) {
                return;
            }
            if (atRule.value && context_1.antDesignColorMap.has(atRule.name)) {
                if (atRule.value.includes('@')) {
                    const mapValue = context_1.antDesignColorMap.get(value);
                    mapValue && context_1.antDesignColorMap.set(atRule.name, mapValue);
                }
                else {
                    context_1.antDesignColorMap.set(atRule.name, atRule.value);
                }
                const varName = atRule.name.replace(/^@/, '');
                const hasAlias = color_1.ANT_DESIGN_COLOR_MAP.get(varName);
                atRule.value = `var(--${hasAlias ? atRule.name : varName})`;
            }
        },
        (atRule) => {
            const name = atRule.name;
            const value = atRule.value;
            let includeLessFunc = false;
            for (const funcName of util_1.COLOR_FUNC_NAME_LIST) {
                if (includeLessFunc) {
                    continue;
                }
                if (value?.includes(funcName)) {
                    includeLessFunc = true;
                }
            }
            if (!context_1.antDesignColorMap.has(name) && value && !includeLessFunc) {
                // 暂时只抽取 颜色变量
                if ((0, is_color_1.default)(value)) {
                    context_1.antDesignColorMap.set(name, value);
                    atRule.value = `var(--${name})`;
                }
            }
        },
    ],
});
const processColorFunc = (0, color_func_1.createProcessColorFunc)();
for (const processFunc of processColorFunc) {
    (0, index_1.mergeRule)(rule, processFunc);
}
exports.default = rule;
